==> ejc-wzxt-api-3.0.0-20230810.084205-149-sources.jar: com/ejianc/business/wzxt/api/IOrderApi.java <==
package com.ejianc.business.wzxt.api;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ejianc.business.wzxt.hystrix.OrderHystrix;
import com.ejianc.business.wzxt.vo.OrderProjectVO;
import com.ejianc.business.wzxt.vo.OrderVO;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;

/**
 * 获取订单内所有项目方法
 * 
 * @author yqls
 *
 */
@FeignClient(name= "ejc-wzxt-web", url="${common.env.feign-client-url}", path="ejc-wzxt-web", fallback = OrderHystrix.class)
public interface IOrderApi {

	/**
	 * 根据供应商主键获取订单里的项目
	 * @param
	 * @return
	 */
	@GetMapping(value = "/api/order/queryOrderProjects")
	public CommonResponse<IPage<OrderProjectVO>> queryOrderProjects(@RequestParam(defaultValue = "1") Integer pageNumber,
																	@RequestParam(defaultValue = "10") Integer pageSize,
																	@RequestParam(value = "condition", required = false) String condition,
																	@RequestParam(value = "searchText", required = false) String searchText);

	/**
	 * 根据物资明细id 获取订单详情
	 *
	 */
	@RequestMapping(
			value = {"/api/delivery/queryOrderByDetailId"},
			method = {RequestMethod.GET}
	)
	CommonResponse<OrderVO> queryOrderByDetailId(@RequestParam("detailId") Long detailId);
}

==> ejc-wzxt-api-3.0.0-20230824.022254-158-sources.jar: com/ejianc/business/wzxt/api/IOrderApi.java <==
package com.ejianc.business.wzxt.api;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ejianc.business.wzxt.hystrix.OrderHystrix;
import com.ejianc.business.wzxt.vo.OrderProjectVO;
import com.ejianc.business.wzxt.vo.OrderVO;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;

/**
 * 获取订单内所有项目方法
 * 
 * @author yqls
 *
 */
@FeignClient(name= "ejc-wzxt-web", url="${common.env.feign-client-url}", path="ejc-wzxt-web", fallback = OrderHystrix.class)
public interface IOrderApi {

	/**
	 * 根据供应商主键获取订单里的项目
	 * @param
	 * @return
	 */
	@GetMapping(value = "/api/order/queryOrderProjects")
	public CommonResponse<IPage<OrderProjectVO>> queryOrderProjects(@RequestParam(defaultValue = "1") Integer pageNumber,
																	@RequestParam(defaultValue = "10") Integer pageSize,
																	@RequestParam(value = "condition", required = false) String condition,
																	@RequestParam(value = "searchText", required = false) String searchText);

	/**
	 * 根据物资明细id 获取订单详情
	 *
	 */
	@RequestMapping(
			value = {"/api/order/queryOrderByDetailId"},
			method = {RequestMethod.GET}
	)
	CommonResponse<OrderVO> queryOrderByDetailId(@RequestParam("detailId") Long detailId);
}
